@@ -2,9 +2,9 @@ package Win32::IE::Form;
 use strict;
 use warnings;
 
-# $Id: Form.pm 397 2005-08-24 10:43:44Z abeltje $
+# $Id: Form.pm 231 2005-01-04 14:56:08Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.005';
+$VERSION = '0.002';
 
 =head1 NAME
 
@@ -130,7 +130,7 @@ sub name {
     my $self = shift;
     my $form = $$self;
 
-    return ref $form->{name} ? $self->attr( 'name' ) : $form->{name};
+    return $form->{name}
 }
 
 =head2 $form->inputs()
@@ -145,23 +145,17 @@ sub inputs {
     my $form = $$self;
 
     my $ok_tags = join "|", qw( BUTTON INPUT SELECT TEXTAREA );
-    my( @inputs, %radio_seen );
-    $form->elements->length or return;
-    for ( my $i = 0; $i < $form->elements->length; $i++ ) {
-        next unless $form->elements( $i );
-        next unless grep /tagName/ => keys %{ $form->elements( $i ) };
-        next unless $form->elements( $i )->tagName =~ /$ok_tags/i;
+    my( @inputs, %radio_seen ) ;
+    for ( my $i = 0; $i < $form->all->length; $i++ ) {
+        next unless $form->all( $i )->tagName =~ /$ok_tags/i;
+        if ( lc( $form->all( $i )->tagName ) eq 'input' &&
+             lc( $form->all( $i )->type    ) eq 'radio' ) {
 
-        my $hastype = grep /^type$/i => keys %{ $form->elements( $i ) };
-        if ( lc( $form->elements( $i )->tagName ) eq 'input' &&
-            $hastype                                            &&
-            lc( $form->elements( $i )->type    ) eq 'radio' ) {
-
-            $radio_seen{ $form->elements( $i )->name }++ or
-                push @inputs, Win32::IE::Input->new($form->elements( $i ));
+            $radio_seen{ $form->all( $i )->name }++ or
+                push @inputs, Win32::IE::Input->new( $form->all( $i ) );
 
         } else {
-            push @inputs, Win32::IE::Input->new($form->elements( $i ));
+            push @inputs, Win32::IE::Input->new( $form->all( $i ) );
         }
     }
 
@@ -211,7 +205,6 @@ sub find_input {
         return @res;
     } else {
         $index ||= 1;
-
         for my $input ( $self->inputs ) {
             if ( defined $name ) {
                 $input->name or next;
